@@ -6,9 +6,9 @@
 #' abundances from and to a \code{.json} file format
 #'
 #' @param fname the path of a \code{.json} file
-#' @return if \code{fname==NULL}, returns a \code{.json} string
+#' @return if \code{fname=NULL}, returns a \code{.json} string
 #' @examples
-#' json <- system.file("defaults.json",package="IsoplotR")
+#' json <- system.file("constants.json",package="IsoplotR")
 #' settings(json)
 #' print(settings())
 #' @export
@@ -20,6 +20,10 @@ settings <- function(fname=NULL){
         prefs <- fromJSON(file=fname)
         .IsoplotR$lambda <- prefs$lambda
         .IsoplotR$iratio <- prefs$iratio
+        .IsoplotR$imass <- prefs$imass
+        .IsoplotR$etchfact <- prefs$etchfact
+        .IsoplotR$tracklength <- prefs$tracklength
+        .IsoplotR$mindens <- prefs$mindens
     }
 }
 
@@ -30,28 +34,29 @@ settings <- function(fname=NULL){
 #' @param nuclide the nuclide name
 #' @param x new value for the decay constant
 #' @param e new value for the decay constant uncertainty
-#' @return if \code{x==e==NULL}, returns a two-item vector containing
-#'     the decay constant [in Ma-1] and its standard error,
+#' @return if \code{x=e=NULL}, returns a two-item vector containing
+#'     the decay constant [in Myr\eqn{^{-1}}] and its standard error,
 #'     respectively.
 #' @examples print(lambda('U238'))
 #' # use the decay constant of Kovarik and Adams (1932)
 #' lambda('U238',0.0001537,0.0000068)
 #' print(lambda('U238'))
 #' @references
-#' U: Jaffey, A. H., et al. "Precision measurement of half-lives and
-#' specific activities of U235 and U238." Physical Review C 4.5 (1971): 1889.
 #'
-#' Th: Le Roux, L. J., and L. E. Glendenin. "Half-life of 232Th.
+#' U: Jaffey, A. H., et al. "Precision measurement of half-lives and
+#' specific activities of U\eqn{^{235}} and U\eqn{^{238}}." Physical Review C 4.5 (1971): 1889.
+#'
+#' Th: Le Roux, L. J., and L. E. Glendenin. "Half-life of \eqn{^{232}}Th.
 #' "Proceedings of the National Meeting on Nuclear Energy, Pretoria,
 #' South Africa. 1963.
 #'
-#' Sm: Lugmair, G. W., and K. Marti. "Lunar initial 143Nd/144Nd: differential
+#' Sm: Lugmair, G. W., and K. Marti. "Lunar initial \eqn{^{143}}Nd/\eqn{^{144}}Nd: differential
 #' evolution of the lunar crust and mantle." Earth and Planetary Science
 #' Letters 39.3 (1978): 349-357.
 #' 
 #' Ar: Renne, Paul R., et al. "Response to the comment by WH Schwarz et al. on
-#' "Joint determination of 40K decay constants and 40Ar*/40K for the Fish Canyon
-#' sanidine standard, and improved accuracy for 40 Ar/39 Ar geochronology"
+#' "Joint determination of 40K decay constants and \eqn{^{40}}Ar*/\eqn{^{40}}K for the Fish Canyon
+#' sanidine standard, and improved accuracy for \eqn{^{40}}Ar/\eqn{^{39}}Ar geochronology"
 #' by PR Renne et al.(2010)." Geochimica et Cosmochimica Acta 75.17 (2011): 5097-5100.
 #'
 #' @export
@@ -113,3 +118,21 @@ iratio <- function(ratio,x=NULL,e=NULL){
     if (is.numeric(x)) .IsoplotR$iratio[[ratio]][1] <- x
     if (is.numeric(e)) .IsoplotR$iratio[[ratio]][2] <- e
 }
+
+imass <- function(nuclide,x=NULL,e=NULL){
+    if (is.null(x) & is.null(e)) return(.IsoplotR$imass[[nuclide]])
+    if (is.numeric(x)) .IsoplotR$imass[[nuclide]][1] <- x
+    if (is.numeric(e)) .IsoplotR$imass[[nuclide]][2] <- e
+}
+etchfact <- function(mineral,x=NULL){
+    if (is.null(x)) return(.IsoplotR$etchfact[[mineral]])
+    if (is.numeric(x)) .IsoplotR$etchfact[[mineral]] <- x
+}
+tracklength <- function(mineral,x=NULL){
+    if (is.null(x)) return(.IsoplotR$tracklength[[mineral]])
+    if (is.numeric(x)) .IsoplotR$tracklength[[mineral]] <- x
+}
+mindens <- function(mineral,x=NULL){
+    if (is.null(x)) return(.IsoplotR$mindens[[mineral]])
+    if (is.numeric(x)) .IsoplotR$mindens[[mineral]] <- x
+}
